@@ -5,7 +5,6 @@
 Module that contains abstract definition of basic DCC progress bar
 """
 
-from tpDcc import register
 from tpDcc.libs.python import decorators
 
 
@@ -42,6 +41,3 @@ class AbstractProgressBar(object):
 
     def inc(self, inc=1):
         self.__class__.inc_value += inc
-
-
-register.register_class('DccProgressBar', AbstractProgressBar)
