@@ -29,7 +29,7 @@ class DccTool(plugin.Plugin, object):
     FILE_NAME = ''
     FULL_NAME = ''
 
-    def __init__(self, manager, config=None, settings=None, *args, **kwargs):
+    def __init__(self, manager, config=None, settings=None, dev=False, *args, **kwargs):
         super(DccTool, self).__init__(manager=manager)
 
         self._tool = list()
@@ -37,6 +37,7 @@ class DccTool(plugin.Plugin, object):
         self._bootstrap = list()
         self._attacher = None
         self._settings = settings
+        self._dev = dev
 
     @property
     def config(self):
@@ -50,6 +51,10 @@ class DccTool(plugin.Plugin, object):
     def attacher(self):
         return self._attacher
 
+    @property
+    def dev(self):
+        return self._dev
+
     @decorators.abstractmethod
     def creator(self):
         """
@@ -87,7 +92,7 @@ class DccTool(plugin.Plugin, object):
         return {
             'name': 'DccTool',
             'id': 'tpDcc-tools-tool',
-            'supported_dccs': [],
+            'supported_dccs': dict(),
             'creator': 'Tomas Poveda',
             'icon': 'tpdcc',
             'tooltip': '',
@@ -189,12 +194,14 @@ class DccTool(plugin.Plugin, object):
         Function that launches current tool
         :param frameless_active: bool, Whether the tool will be launch in frameless mode or not
         :param tool_kwargs: dict, dictionary of arguments to launch tool with
+        :param attacher_class:
         :return:
         """
 
         tool_config_dict = self.config_dict()
         tool_name = tool_config_dict.get('name', None)
         tool_id = tool_config_dict.get('id', None)
+        tool_size = tool_config_dict.get('size', None)
         if not tool_name or not tool_id:
             tp.logger.warning('Impossible to run tool "{}" with id: "{}"'.format(tool_name, tool_id))
             return None
@@ -231,6 +238,8 @@ class DccTool(plugin.Plugin, object):
         toolset_inst.set_attacher(self._attacher)
         self._attacher.setWindowIcon(toolset_inst.get_icon())
         self._attacher.setWindowTitle('{} - {}'.format(self._attacher.windowTitle(), self.VERSION))
+        if tool_size:
+            self._attacher.resize(tool_size[0], tool_size[1])
         self._attacher.show()
 
         return self._attacher
@@ -277,6 +286,7 @@ class DccTool(plugin.Plugin, object):
         try:
             kwargs['settings'] = self._settings
             kwargs['config'] = self._config
+            kwargs['dev'] = self._dev
             tool_data = self.launch(*args, **kwargs)
             if tool_data and tool_data.get('tool') is not None:
                 tool_data['tool'].ID = self.ID
@@ -289,13 +299,14 @@ class DccTool(plugin.Plugin, object):
                     #     uid = "{0} [{1}]".format(self.uiData["label"], str(uuid.uuid4()))
                     ui_label = self._config.get('name', default='')
                     ui_icon = self._config.get('icon', default='tpdcc')
-                    from tpDcc.dccs.maya.ui import window
-                    bootstrap_widget = window.BootStrapWidget(
-                        tool_data['tool'], title=ui_label, icon=tp.ResourcesMgr().icon(ui_icon), uid=uid)
-                    tool_data['bootstrap'] = bootstrap_widget
-                    tool_data['bootstrap'].show(
-                        retain=False, dockable=True, tabToControl=('AttributeEditor', -1), floating=False)
-                    self._bootstrap.append(bootstrap_widget)
+                    if tp.is_maya():
+                        from tpDcc.dccs.maya.ui import window
+                        bootstrap_widget = window.BootStrapWidget(
+                            tool_data['tool'], title=ui_label, icon=tp.ResourcesMgr().icon(ui_icon), uid=uid)
+                        tool_data['bootstrap'] = bootstrap_widget
+                        tool_data['bootstrap'].show(
+                            retain=False, dockable=True, tabToControl=('AttributeEditor', -1), floating=False)
+                        self._bootstrap.append(bootstrap_widget)
         except Exception:
             exc_type, exc_value, exc_tb = sys.exc_info()
             traceback.print_exception(exc_type, exc_value, exc_tb)
